@@ -2,6 +2,7 @@
 # Call 'make' in 'src/vhdl' to regenerate:
 #
 from enum import IntEnum, unique
+
 from pyTooling.Decorators import export
 
 from pyGHDL.libghdl._decorator import BindToLibGHDL
@@ -25,7 +26,7 @@ def get_fields_first(K: IirKind) -> int:
 
     :param K: Node to get first array index from.
     """
-    return 0
+    return 0  # pragma: no cover
 
 
 @export
@@ -42,14 +43,14 @@ def get_fields_last(K: IirKind) -> int:
 
     :param K: Node to get last array index from.
     """
-    return 0
+    return 0  # pragma: no cover
 
 
 @export
 @BindToLibGHDL("vhdl__nodes_meta__get_field_by_index")
 def get_field_by_index(K: IirKind) -> int:
     """"""
-    return 0
+    return 0  # pragma: no cover
 
 
 @export
@@ -475,42 +476,41 @@ class fields(IntEnum):
     End_Has_Reserved_Id = 355
     End_Has_Identifier = 356
     End_Has_Postponed = 357
-    Has_Label = 358
-    Has_Begin = 359
-    Has_End = 360
-    Has_Is = 361
-    Has_Pure = 362
-    Has_Body = 363
-    Has_Parameter = 364
-    Has_Component = 365
-    Has_Identifier_List = 366
-    Has_Mode = 367
-    Has_Class = 368
-    Has_Delay_Mechanism = 369
-    Suspend_Flag = 370
-    Covered_Flag = 371
-    Stop_Flag = 372
-    Is_Ref = 373
-    Is_Forward_Ref = 374
-    Psl_Property = 375
-    Psl_Sequence = 376
-    Psl_Declaration = 377
-    Psl_Expression = 378
-    Psl_Boolean = 379
-    PSL_Clock = 380
+    Has_Begin = 358
+    Has_End = 359
+    Has_Is = 360
+    Has_Pure = 361
+    Has_Body = 362
+    Has_Parameter = 363
+    Has_Component = 364
+    Has_Identifier_List = 365
+    Has_Mode = 366
+    Has_Class = 367
+    Has_Delay_Mechanism = 368
+    Suspend_Flag = 369
+    Covered_Flag = 370
+    Stop_Flag = 371
+    Is_Ref = 372
+    Is_Forward_Ref = 373
+    Psl_Property = 374
+    Psl_Sequence = 375
+    Psl_Declaration = 376
+    Psl_Expression = 377
+    Psl_Boolean = 378
+    PSL_Clock = 379
+    PSL_Abort = 380
     PSL_NFA = 381
     PSL_Nbr_States = 382
     PSL_Clock_Sensitivity = 383
     PSL_EOS_Flag = 384
-    PSL_Abort_Flag = 385
-    Count_Expression = 386
-    Clock_Expression = 387
-    Default_Clock = 388
-    Foreign_Node = 389
-    Suspend_State_Index = 390
-    Suspend_State_Chain = 391
-    Suspend_State_Last = 392
-    Suspend_State_Decl = 393
+    Count_Expression = 385
+    Clock_Expression = 386
+    Default_Clock = 387
+    Foreign_Node = 388
+    Suspend_State_Index = 389
+    Suspend_State_Chain = 390
+    Suspend_State_Last = 391
+    Suspend_State_Decl = 392
 
 
 def Get_Boolean(node, field):
@@ -2793,12 +2793,6 @@ def Has_End_Has_Postponed(kind: IirKind) -> bool:
     """"""
 
 
-@export
-@BindToLibGHDL("vhdl__nodes_meta__has_has_label")
-def Has_Has_Label(kind: IirKind) -> bool:
-    """"""
-
-
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_has_begin")
 def Has_Has_Begin(kind: IirKind) -> bool:
@@ -2931,6 +2925,12 @@ def Has_PSL_Clock(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_psl_abort")
+def Has_PSL_Abort(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_psl_nfa")
 def Has_PSL_NFA(kind: IirKind) -> bool:
@@ -2955,12 +2955,6 @@ def Has_PSL_EOS_Flag(kind: IirKind) -> bool:
     """"""
 
 
-@export
-@BindToLibGHDL("vhdl__nodes_meta__has_psl_abort_flag")
-def Has_PSL_Abort_Flag(kind: IirKind) -> bool:
-    """"""
-
-
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_count_expression")
 def Has_Count_Expression(kind: IirKind) -> bool:
